import { Route, Switch } from 'wouter';
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { Toaster } from '@/components/ui/toaster';
import { HelmetProvider } from 'react-helmet-async';
import { Suspense, lazy } from 'react';
import ErrorBoundary from '@/components/ErrorBoundary';
import { PageLoader } from '@/components/LoadingSpinner';

// Lazy load components for better performance
const Welcome = lazy(() => import('@/components/OptimizedWelcome'));
const Home = lazy(() => import('@/pages/Home'));
const Login = lazy(() => import('@/pages/Login'));
const Admin = lazy(() => import('@/pages/Admin'));
const ProviderDashboard = lazy(() => import('@/pages/ProviderDashboard'));
const Terms = lazy(() => import('@/pages/Terms'));
const Privacy = lazy(() => import('@/pages/Privacy'));
const SecureForm = lazy(() => import('@/pages/SecureForm'));
const AccountDetailPage = lazy(() => import('@/pages/AccountDetailPage'));
const NotFound = lazy(() => import('@/pages/not-found'));
const LinkedInRentingService = lazy(() => import('@/pages/LinkedInRentingService'));
const EarnMoneyLinkedIn = lazy(() => import('@/pages/EarnMoneyLinkedIn'));
const BuyLinkedInOnRent = lazy(() => import('@/pages/BuyLinkedInOnRent'));
const LinkedInMarketplace = lazy(() => import('@/pages/LinkedInMarketplace'));
const SocialMediaAccountRental = lazy(() => import('@/pages/SocialMediaAccountRental'));
const Services = lazy(() => import('@/pages/Services'));
const ServerError = lazy(() => import('@/pages/ServerError'));
import { ProtectedRoute } from '@/lib/protected-route';
import SecureFormAdmin from "@/pages/SecureFormAdmin";

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 1000 * 60 * 5, // 5 minutes
      gcTime: 1000 * 60 * 30, // 30 minutes
      refetchOnWindowFocus: false,
      refetchOnMount: false,
      retry: 1,
    },
  },
});

function App() {
  return (
    <HelmetProvider>
      <QueryClientProvider client={queryClient}>
        <ErrorBoundary>
          <div className="min-h-screen bg-blue-50">
            <Suspense fallback={<PageLoader />}>
              <Switch>
                <Route path="/" component={Welcome} />
              <Route path="/home" component={Home} />
              <Route path="/login" component={Login} />
              <Route path="/admin">
                {() => {
                  const Component = Admin;
                  return <ProtectedRoute path="/admin" component={Component} />;
                }}
              </Route>
              <Route path="/admin/secure-forms">
                {() => {
                  const Component = SecureFormAdmin;
                  return <ProtectedRoute path="/admin/secure-forms" component={Component} />;
                }}
              </Route>
              <Route path="/provider-dashboard">
                {() => {
                  const Component = ProviderDashboard;
                  return <ProtectedRoute path="/provider-dashboard" component={Component} />;
                }}
              </Route>
              <Route path="/terms" component={Terms} />
              <Route path="/privacy" component={Privacy} />
              <Route path="/secure-form/:token" component={SecureForm} />
              <Route path="/account/:id" component={AccountDetailPage} />
              <Route path="/linkedin-renting-service" component={LinkedInRentingService} />
              <Route path="/earn-money-linkedin" component={EarnMoneyLinkedIn} />
              <Route path="/buy-linkedin-on-rent" component={BuyLinkedInOnRent} />
              <Route path="/linkedin-marketplace" component={LinkedInMarketplace} />
              <Route path="/social-media-account-rental" component={SocialMediaAccountRental} />
              <Route path="/services" component={Services} />
              <Route path="/500" component={ServerError} />
              <Route component={NotFound} />
              </Switch>
            </Suspense>
          </div>
          <Toaster />
        </ErrorBoundary>
      </QueryClientProvider>
    </HelmetProvider>
  );
}

export default App;